# policy creation
resource "aws_iam_policy" "terraform-ec2-read-access" {
  name        = "terraform-ec2-read-access"
  description = "ec2-read-access"
  /* jsonencode better than EOF. EOF breaks the new terraform code. */
  policy = jsonencode({
    "Version" : "2012-10-17",
    "Statement" : [
      {
        "Sid" : "VisualEditor0",
        "Effect" : "Allow",
        "Action" : [
          "ec2:GetDefaultCreditSpecification",
          "ec2:GetManagedPrefixListEntries",
          "ec2:DescribeTags",
          "ec2:GetCoipPoolUsage",
          "ec2:DescribeVpnConnections",
          "ec2:GetEbsEncryptionByDefault",
          "ec2:GetCapacityReservationUsage",
          "ec2:DescribeVolumesModifications",
          "ec2:GetHostReservationPurchasePreview",
          "ec2:DescribeFastSnapshotRestores",
          "ec2:GetConsoleScreenshot",
          "ec2:GetReservedInstancesExchangeQuote",
          "ec2:GetAssociatedEnclaveCertificateIamRoles",
          "ec2:GetConsoleOutput",
          "ec2:GetPasswordData",
          "ec2:GetLaunchTemplateData",
          "ec2:DescribeScheduledInstances",
          "ec2:GetSerialConsoleAccessStatus",
          "ec2:GetAssociatedIpv6PoolCidrs",
          "ec2:GetFlowLogsIntegrationTemplate",
          "ec2:DescribeScheduledInstanceAvailability",
          "ec2:GetManagedPrefixListAssociations",
          "ec2:GetEbsDefaultKmsKeyId",
          "ec2:DescribeElasticGpus"
        ],
        "Resource" : "*"
      }
    ]
  })
  tags = {
    "createdby" = "terraform"
  }
}

# user creation
resource "aws_iam_user" "newusers" {
  count = length(var.usernames)
  name  = element(var.usernames, count.index)
  tags = {
    "createdby" = "terraform"
  }
}

# attaching policy to the user
resource "aws_iam_user_policy_attachment" "terraform-user-policy-attachment" {
  count      = length(var.usernames)
  user       = element(aws_iam_user.newusers.*.name, count.index)
  policy_arn = aws_iam_policy.terraform-ec2-read-access.arn
}
